import { Action, getModule, Module, MutationAction, VuexModule } from 'vuex-module-decorators';
import store from '@/store';
import http from '@/utils/request';
import { url } from '@/utils/url';
import { session } from '@/store/modules/session';
// import { page } from '@/utils/page';
import vm from '@/main';

class OrderInInfo {
  productDescZh?: string;
  qty?: string;
  custCode?: string;
  custCodeName?: string;
  productCode?: string;
  locCode?: string;
  costCenter?: string;
}

@Module({
  namespaced: true,
  dynamic: true,
  store,
  name: 'product.warehouse.wholeCollect',
})
export class wholeCollect extends VuexModule {
  /**
   * 库位地点列表
   */
  WlList = [];

  /**
   * 物料型号类型
   */
  // modelType = [
  //   { label: '内销', value: '0' },
  //   { label: '外销', value: '1' },
  //   { label: '样机', value: '2' },
  //   { label: '半成品', value: '4' },
  // ];
  /**
   * 隐藏看单号
   */
  dnNo = '';
  /**
   * 看单号查询结果
   */
  orderInInfo: OrderInInfo = new OrderInInfo();

  // /**
  //  * 更新看单明细库位
  //  * @param kw 库位
  //  */
  // @Mutation
  // updateOrderInInfoListKw(kw: string) {
  //   this.orderInInfoList = this.orderInInfoList.map((item) => {
  //     item.kw = kw;
  //     return item;
  //   });
  // }

  /**
   * 查询库位列表
   */
  @MutationAction
  async queryLocation() {
    const result: any = await http.get(url.warehouse.wholeTransfer.list, {
      params: {
        factoryCode: session.factoryCode,
        loginName: session.loginName,
      },
    });
    // console.log('库位数据',result)
    const WlList = result.data.map((_: any) => ({
      label: _.locationCode,
      value: _.locationCode,
    }));
    return { WlList };
  }

  /**
   * 查询单号
   * 查询DN单号
   * @param dnNo
   */
  @MutationAction
  async getProductCode(barcode: string) {
    const res: any = await http.post(url.warehouse.wholeTransfer.content, {
      barcode,
      factoryCode: session.factoryCode,
      loginName: session.loginName,
    });
    console.log('获取来的数据', res.data.records);
    const orderInInfo = res.data.records[0] || {};
    if (orderInInfo.custCode == '0') {
      orderInInfo.custCodeName = vm.$t('message.Warehouse_NX') as any;
    } else if (orderInInfo.custCode == '1') {
      orderInInfo.custCodeName = vm.$t('message.Warehouse_WX') as any;
    } else if (orderInInfo.custCode == '2') {
      orderInInfo.custCodeName = vm.$t('message.Warehouse_YJ') as any;
    } else if (orderInInfo.custCode == '4') {
      orderInInfo.custCodeName = vm.$t('message.Warehouse_BCP') as any;
    }
    return { orderInInfo };
  }

  @MutationAction
  async onTakeoutConfirm(list: any[]) {
    const records: any = await http.post(url.warehouse.rowTransfer.commit, list);
    if (records.code == 1) {
      uni.showToast({ icon: 'success', title: 'success' });
      // uni.navigateTo({ url: page.product.warehouse.index });
    }
    return {};
  }
  // /**
  //  * 提交看单明细
  //  */
  // @MutationAction
  // async submitOrderInEnter() {
  //   const list = (this.state as any).orderInInfoList.map((item: any) => {
  //     item.orderStatus = item.checked ? '2' : '1';
  //     item.requestAmount = item.checked ? item.y : '0';
  //     return item;
  //   });
  //   const result: any = await http.post(url.material.DNorderin.enter, {
  //     dnNo: this.dnNo,
  //     factoryCode: '1999',
  //     loginName: '1999',
  //     list,
  //   });
  //   uni.showToast({
  //     icon: 'none',
  //     title: result.msg,
  //   });
  //   const orderInInfoList = result.list.sort(
  //     (a: any, b: any) => Number(a.accountingStatus) - Number(b.accountingStatus),
  //   );
  //   return { orderInInfoList };
  // }

  /**
   * 修改库位
   */
  @Action({ commit: 'updateCheckedOrderInInfoListKw' })
  async changeOrderInLocation(kw: string) {
    await http.post('/material/orderin/enter', {
      loginName: session.loginName,
      warehouseCode: '',
      factoryCode: session.factoryCode,
      locationCode: kw,
    });
    return kw;
  }
}

export default getModule(wholeCollect);
